@@ -70,7 +70,11 @@ deepin_reader::Document *deepin_reader::DocumentFactory::getDocument(const int &
         qDebug() << "正在解压文档..." << targetDoc;
         QString unzipCommand = "unzip " + targetDoc;
         qDebug() << "执行命令: " << unzipCommand;
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
         decompressor.start(unzipCommand);
+#else
+        decompressor.startCommand(unzipCommand);
+#endif
         if (!decompressor.waitForStarted()) {
             qInfo() << "start unzip failed";
             error = deepin_reader::Document::ConvertFailed;
@@ -111,7 +115,11 @@ deepin_reader::Document *deepin_reader::DocumentFactory::getDocument(const int &
         QString pandocCommand = QString("pandoc %1 --data-dir=%2 -o %3").arg(targetDoc).arg(pandocDataDir).arg(tmpHtmlFilePath);
 
         qDebug() << "执行命令: " << pandocCommand;
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
         converter.start(pandocCommand);
+#else
+        converter.startCommand(pandocCommand);
+#endif
         if (!converter.waitForStarted()) {
             qInfo() << "start pandoc failed";
             error = deepin_reader::Document::ConvertFailed;
@@ -144,7 +152,11 @@ deepin_reader::Document *deepin_reader::DocumentFactory::getDocument(const int &
 
         QString htmltopdfCommand = prefix + "/lib/deepin-reader/htmltopdf " +  tmpHtmlFilePath + " " + realFilePath;
         qDebug() << "执行命令: " << htmltopdfCommand;
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
         converter2.start(htmltopdfCommand);
+#else
+        converter2.startCommand(htmltopdfCommand);
+#endif
         if (!converter2.waitForStarted()) {
             qInfo() << "start htmltopdf failed";
             error = deepin_reader::Document::ConvertFailed;
